==> jc-1.4.0.tar.gz: gnu/java/security/provider/DSAParameters.h <==
// public class gnu.java.security.provider.DSAParameters

// class file dependencies
// @dep_class e2d97b5820c28143 gnu_java_security_provider_DSAParameters
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fe4af2c744a13852 java_security_AlgorithmParametersSpi

// header file dependencies
// @dep_header java_security_AlgorithmParametersSpi

#include "java/security/AlgorithmParametersSpi.h"

#ifndef _JC_gnu_java_security_provider_DSAParameters_H_
#define _JC_gnu_java_security_provider_DSAParameters_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_DSAParameters$sub_refs	_jc_gnu_java_security_provider_DSAParameters$sub_refs;
typedef struct _jc_gnu_java_security_provider_DSAParameters$sub_nonrefs	_jc_gnu_java_security_provider_DSAParameters$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAParameters$refs	_jc_gnu_java_security_provider_DSAParameters$refs;
typedef struct _jc_gnu_java_security_provider_DSAParameters$nonrefs	_jc_gnu_java_security_provider_DSAParameters$nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAParameters$object	_jc_gnu_java_security_provider_DSAParameters$object;

typedef struct _jc_gnu_java_security_provider_DSAParameters$fields_struct	_jc_gnu_java_security_provider_DSAParameters$fields_struct;
typedef const struct _jc_gnu_java_security_provider_DSAParameters$vmethods	_jc_gnu_java_security_provider_DSAParameters$vmethods;
typedef const struct _jc_gnu_java_security_provider_DSAParameters$vtable	_jc_gnu_java_security_provider_DSAParameters$vtable;
typedef const struct _jc_gnu_java_security_provider_DSAParameters$vtype	_jc_gnu_java_security_provider_DSAParameters$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_DSAParameters$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24DSAParameterSpec;
};
extern _jc_gnu_java_security_provider_DSAParameters$fields_struct _jc_gnu_java_security_provider_DSAParameters$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_DSAParameters$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *);

// Virtual methods
extern _jc_byte_array *_jc_gnu_java_security_provider_DSAParameters$method$engineGetEncoded$c6f5908664ac2899(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *);
extern _jc_byte_array *_jc_gnu_java_security_provider_DSAParameters$method$engineGetEncoded$e53c01cc263f9e1e(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_gnu_java_security_provider_DSAParameters$method$engineGetParameterSpec$5324b6890b10eccd(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_java_lang_Class$object *);
extern void _jc_gnu_java_security_provider_DSAParameters$method$engineInit$97ee0e7fb590a770(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_object *);
extern void _jc_gnu_java_security_provider_DSAParameters$method$engineInit$02e0befd93d9fd30(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_byte_array *);
extern void _jc_gnu_java_security_provider_DSAParameters$method$engineInit$931dff8137fe24b0(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_byte_array *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_DSAParameters$method$engineToString$6f451262668adb9f(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineGetEncoded$c6f5908664ac2899;
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineGetEncoded$e53c01cc263f9e1e;
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineGetParameterSpec$5324b6890b10eccd;
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineInit$97ee0e7fb590a770;
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineInit$02e0befd93d9fd30;
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineInit$931dff8137fe24b0;
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineToString$6f451262668adb9f;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_provider_DSAParameters$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_provider_DSAParameters$vmethods {
	_jc_byte_array	*(*engineGetEncoded$c6f5908664ac2899)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *);
	_jc_byte_array	*(*engineGetEncoded$e53c01cc263f9e1e)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*engineGetParameterSpec$5324b6890b10eccd)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_java_lang_Class$object *);
	void	(*engineInit$97ee0e7fb590a770)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_object *);
	void	(*engineInit$02e0befd93d9fd30)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_byte_array *);
	void	(*engineInit$931dff8137fe24b0)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_byte_array *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*engineToString$6f451262668adb9f)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *);
};

// Vtable
struct _jc_gnu_java_security_provider_DSAParameters$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_AlgorithmParametersSpi$vmethods	java_security_AlgorithmParametersSpi;
	_jc_gnu_java_security_provider_DSAParameters$vmethods	gnu_java_security_provider_DSAParameters;
};

// Vtype
struct _jc_gnu_java_security_provider_DSAParameters$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_DSAParameters$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAParameters$sub_refs {
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAParameters$refs {
    _jc_gnu_java_security_provider_DSAParameters$sub_refs	gnu_java_security_provider_DSAParameters;
    _jc_java_security_AlgorithmParametersSpi$sub_refs	java_security_AlgorithmParametersSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAParameters$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAParameters$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_AlgorithmParametersSpi$sub_nonrefs	java_security_AlgorithmParametersSpi;
    _jc_gnu_java_security_provider_DSAParameters$sub_nonrefs	gnu_java_security_provider_DSAParameters;
};

// Object instance structure
struct _jc_gnu_java_security_provider_DSAParameters$object {
	_jc_gnu_java_security_provider_DSAParameters$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_DSAParameters$vtype	*vtype;
	_jc_gnu_java_security_provider_DSAParameters$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_DSAParameters$vtype _jc_gnu_java_security_provider_DSAParameters$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_DSAParameters, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_DSAParameters$class_object;

#endif	/* _JC_gnu_java_security_provider_DSAParameters_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/DSAParameters.h <==
// public class gnu.java.security.provider.DSAParameters

// class file dependencies
// @dep_class e2d97b5820c28143 gnu_java_security_provider_DSAParameters
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fe4af2c744a13852 java_security_AlgorithmParametersSpi

// header file dependencies
// @dep_header java_security_AlgorithmParametersSpi

#include "java/security/AlgorithmParametersSpi.h"

#ifndef _JC_gnu_java_security_provider_DSAParameters_H_
#define _JC_gnu_java_security_provider_DSAParameters_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_DSAParameters$sub_refs	_jc_gnu_java_security_provider_DSAParameters$sub_refs;
typedef struct _jc_gnu_java_security_provider_DSAParameters$sub_nonrefs	_jc_gnu_java_security_provider_DSAParameters$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAParameters$refs	_jc_gnu_java_security_provider_DSAParameters$refs;
typedef struct _jc_gnu_java_security_provider_DSAParameters$nonrefs	_jc_gnu_java_security_provider_DSAParameters$nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAParameters$object	_jc_gnu_java_security_provider_DSAParameters$object;

typedef struct _jc_gnu_java_security_provider_DSAParameters$fields_struct	_jc_gnu_java_security_provider_DSAParameters$fields_struct;
typedef const struct _jc_gnu_java_security_provider_DSAParameters$vmethods	_jc_gnu_java_security_provider_DSAParameters$vmethods;
typedef const struct _jc_gnu_java_security_provider_DSAParameters$vtable	_jc_gnu_java_security_provider_DSAParameters$vtable;
typedef const struct _jc_gnu_java_security_provider_DSAParameters$vtype	_jc_gnu_java_security_provider_DSAParameters$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_DSAParameters$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24DSAParameterSpec;
};
extern _jc_gnu_java_security_provider_DSAParameters$fields_struct _jc_gnu_java_security_provider_DSAParameters$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_DSAParameters$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_gnu_java_security_provider_DSAParameters$method$engineGetEncoded$c6f5908664ac2899(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_security_provider_DSAParameters$method$engineGetEncoded$e53c01cc263f9e1e(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_provider_DSAParameters$method$engineGetParameterSpec$5324b6890b10eccd(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_DSAParameters$method$engineInit$97ee0e7fb590a770(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_DSAParameters$method$engineInit$02e0befd93d9fd30(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_DSAParameters$method$engineInit$931dff8137fe24b0(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_byte_array *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_DSAParameters$method$engineToString$6f451262668adb9f(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineGetEncoded$c6f5908664ac2899;
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineGetEncoded$e53c01cc263f9e1e;
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineGetParameterSpec$5324b6890b10eccd;
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineInit$97ee0e7fb590a770;
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineInit$02e0befd93d9fd30;
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineInit$931dff8137fe24b0;
extern _jc_method _jc_gnu_java_security_provider_DSAParameters$method_info$engineToString$6f451262668adb9f;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_provider_DSAParameters$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_provider_DSAParameters$vmethods {
	_jc_byte_array	*(*engineGetEncoded$c6f5908664ac2899)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*engineGetEncoded$e53c01cc263f9e1e)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineGetParameterSpec$5324b6890b10eccd)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
	void	(*engineInit$97ee0e7fb590a770)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*engineInit$02e0befd93d9fd30)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*engineInit$931dff8137fe24b0)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *, struct _jc_byte_array *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*engineToString$6f451262668adb9f)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameters$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_DSAParameters$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_AlgorithmParametersSpi$vmethods	java_security_AlgorithmParametersSpi;
	_jc_gnu_java_security_provider_DSAParameters$vmethods	gnu_java_security_provider_DSAParameters;
};

// Vtype
struct _jc_gnu_java_security_provider_DSAParameters$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_DSAParameters$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAParameters$sub_refs {
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAParameters$refs {
    _jc_gnu_java_security_provider_DSAParameters$sub_refs	gnu_java_security_provider_DSAParameters;
    _jc_java_security_AlgorithmParametersSpi$sub_refs	java_security_AlgorithmParametersSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAParameters$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAParameters$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_AlgorithmParametersSpi$sub_nonrefs	java_security_AlgorithmParametersSpi;
    _jc_gnu_java_security_provider_DSAParameters$sub_nonrefs	gnu_java_security_provider_DSAParameters;
};

// Object instance structure
struct _jc_gnu_java_security_provider_DSAParameters$object {
	_jc_gnu_java_security_provider_DSAParameters$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_DSAParameters$vtype	*vtype;
	_jc_gnu_java_security_provider_DSAParameters$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_DSAParameters$vtype _jc_gnu_java_security_provider_DSAParameters$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_DSAParameters, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_DSAParameters$class_object;

#endif	/* _JC_gnu_java_security_provider_DSAParameters_H_ */
